@@ -68,7 +68,7 @@ if not os.path.isfile(AUTH_DB_PATH):
 async def _write_file(path, body):
     async with aiofiles.open(path, "wb") as f:
         await f.write(body)
-        f.close()
+        await f.close()
 
 
 def _secure_filename(filename: str) -> str:
@@ -334,7 +334,10 @@ def start_workers(workers: int = CONFIG["CIRCE_WORKERS"]):
     if CONFIG["CIRCE_IMMEDIATE_MODE"]:
         sys.exit("Can't start workers if CIRCE_IMMEDIATE_MODE=1")
     working_directory = os.path.dirname(os.path.abspath(__file__))
-    call(["huey_consumer.py", "tasks.huey", "-w", str(workers)], cwd=working_directory)
+    call(
+        ["huey_consumer.py", "circe.tasks.huey", "-w", str(workers)],
+        cwd=working_directory,
+    )
 
 
 def serve(
